@@ -39,8 +39,11 @@ class AccessRequest(OpenModuleModel):
 def check_recurrence(cls, recurrence, values, **kwargs):
     if recurrence == "":
         return recurrence
-    if recurrence and not values.get("duration"):
-        raise ValueError("set duration when using recurrence")
+    if recurrence:
+        if not values.get("duration"):
+            raise ValueError("set duration when using recurrence")
+        if not values.get("start"):
+            raise ValueError("set start timestamp when using recurrence")
     try:
         rrule.rrulestr(recurrence)
     except Exception as e:
