@@ -80,7 +80,7 @@ class Backend:
             return False
 
     def rpc_check_access(self, request: AccessRequest, _) -> AccessResponse:
-        gate_log_string = f"({request.gateway.gate}/{request.gateway.direction})"
+        gate_log_string = f"({request.gateway.gate}/{request.gateway.direction})" if request.gateway else ""
 
         try:
             accesses = self.check_access(request)
