@@ -2,7 +2,7 @@ import time
 from unittest import TestCase
 
 from openmodule.core import init_openmodule, shutdown_openmodule
-from openmodule.models import Direction
+from openmodule.models.base import Direction
 from openmodule.utils.presence import PresenceListener
 from openmodule_test.eventlistener import MockEvent
 from openmodule_test.presence import PresenceSimulator
