@@ -1,6 +1,6 @@
 from unittest import TestCase
 
-from openmodule.utils.vehicle import Vehicle
+from openmodule.models.vehicle import Vehicle
 
 
 class VehicleTestCase(TestCase):
